@@ -20,26 +20,26 @@ from .network_menu import ManualNetworkConfig, ask_to_configure_network
 from .system_conf import ask_for_bootloader, ask_for_swap, ask_for_uki, select_driver, select_kernel
 
 __all__ = [
-	"ManualNetworkConfig",
-	"UserList",
-	"add_number_of_parallel_downloads",
-	"ask_additional_packages_to_install",
-	"ask_for_a_timezone",
-	"ask_for_additional_users",
-	"ask_for_audio_selection",
-	"ask_for_bootloader",
-	"ask_for_swap",
-	"ask_for_uki",
-	"ask_hostname",
-	"ask_ntp",
-	"ask_to_configure_network",
-	"get_default_partition_layout",
-	"select_archinstall_language",
-	"select_devices",
-	"select_disk_config",
-	"select_driver",
-	"select_kernel",
-	"select_main_filesystem_format",
-	"suggest_multi_disk_layout",
-	"suggest_single_disk_layout",
+	'ManualNetworkConfig',
+	'UserList',
+	'add_number_of_parallel_downloads',
+	'ask_additional_packages_to_install',
+	'ask_for_a_timezone',
+	'ask_for_additional_users',
+	'ask_for_audio_selection',
+	'ask_for_bootloader',
+	'ask_for_swap',
+	'ask_for_uki',
+	'ask_hostname',
+	'ask_ntp',
+	'ask_to_configure_network',
+	'get_default_partition_layout',
+	'select_archinstall_language',
+	'select_devices',
+	'select_disk_config',
+	'select_driver',
+	'select_kernel',
+	'select_main_filesystem_format',
+	'suggest_multi_disk_layout',
+	'suggest_single_disk_layout',
 ]
